package pwc.taxtech.atms.security;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;



@Service
public class JwtAuthenticationService {

    protected final Logger logger = LoggerFactory.getLogger(this.getClass());


    /**
     * 27/12/2018 11:05
     * 用户第一个需鉴权的操作时，从UPM获取用户操作权限存入EhCache，至下一次登陆前从EhCache获取权限进行操作鉴权。
     * [userName]
     * @author Gary J Li
     * @return List<String>
     */
    @Cacheable(value = "apiAuthCache", key = "'userName'")
    public List<String> getApiAuthList(String userName) {
        List<String> apiAuthList = new ArrayList<>();
        apiAuthList.add("user:add");
        apiAuthList.add("user:edit");
        apiAuthList.add("userRole:add");
        apiAuthList.add("userRole:edit");
        apiAuthList.add("role:add");
        apiAuthList.add("role:edit");
        apiAuthList.add("roleCategory:add");
        apiAuthList.add("roleCategory:edit");
        apiAuthList.add("vatApproval:commit");
        apiAuthList.add("vatApproval:check");
        // todo upm return  response
        logger.debug("get Cache from upm :"+"apiAuthCache-"+"key :"+userName + " value :"+String.join("，",apiAuthList));
        return apiAuthList;
    }

    /**
     * 27/12/2018 11:07
     * 用户登陆时服务器EhCache中的用户权限信息。
     * [userName]
     * @author Gary J Li
     *
     */
    @CacheEvict(value = "apiAuthCache", key = "'#userName'")
    public void removeApiAuthList(String userName) {
        logger.debug("remove Cache :"+"apiAuthCache"+"key :"+userName);
    }

}
